==> ssp_api-1.3.3.0-sources.jar: com/cloud/hisavana/sdk/common/util/FileUtil.java <==
package com.cloud.hisavana.sdk.common.util;

import static com.cloud.hisavana.sdk.common.util.AdLogUtil.TAG;

import android.Manifest;
import android.content.Context;
import android.graphics.Bitmap;
import android.os.Build;
import android.os.Environment;
import android.text.TextUtils;

import com.cloud.hisavana.sdk.api.config.SspAd;
import com.transsion.core.CoreUtil;
import com.transsion.core.utils.PermissionUtil;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.Reader;
import java.nio.charset.StandardCharsets;

/**
 * @author peng.sun
 * @data 2017/7/5
 * ========================================
 * CopyRight (c) 2017 TRANSSION.Co.Ltd.
 * All rights reserved.
 */

public class FileUtil {

    /**
     * 获得SDCard/Android/data/你的应用的包名/files/ 路径
     *
     * @return
     */
    public static File getAppDateFilePath() {
        Context context = CoreUtil.getContext();
        if (PermissionUtil.lacksPermissions(Manifest.permission.WRITE_EXTERNAL_STORAGE, Manifest.permission.READ_EXTERNAL_STORAGE)) {
            return null;
        }
        return context.getExternalFilesDir(null);
    }


    /**
     * 获得SDCard/android/data/你的应用包名/cache/路径
     *
     * @return
     */
    public static File getAppDateCachePath() {
        Context context = CoreUtil.getContext();
        return context.getExternalCacheDir();
    }

    /**
     * 该方法会判断当前sd卡是否存在，然后选择缓存地址
     *
     * @param context
     * @param uniqueName
     * @return
     */
    public static File getDiskCacheDir(Context context, String uniqueName) {
        String cachePath;
        if (Environment.MEDIA_MOUNTED.equals(Environment.getExternalStorageState()) || !Environment.isExternalStorageRemovable()) {
            cachePath = context.getExternalCacheDir().getPath();
        } else {
            cachePath = context.getCacheDir().getPath();
        }
        return new File(cachePath + File.separator + uniqueName);
    }

    public static void saveBitmapToFile(File dirFile, Bitmap bm, String fileName) throws IOException {
        if (dirFile == null || bm == null || TextUtils.isEmpty(fileName)) {
            return;
        }
        if (!dirFile.exists()) {
            dirFile.mkdir();
        }
        File myCaptureFile = new File(dirFile + File.separator + fileName);
        BufferedOutputStream bos = new BufferedOutputStream(new FileOutputStream(myCaptureFile));
        bm.compress(Bitmap.CompressFormat.JPEG, 80, bos);
        bos.flush();
        bos.close();
    }

    public static void saveBytesToFile(File dir, byte[] bytes, String fileName) throws IOException {
        if (dir == null || bytes == null || bytes.length == 0 || TextUtils.isEmpty(fileName)) {
            return;
        }
        if (!dir.exists()) {
            dir.mkdir();
        }
        File myCaptureFile = new File(dir + File.separator + fileName);
        BufferedOutputStream bos = new BufferedOutputStream(new FileOutputStream(myCaptureFile));
        bos.write(bytes);
        bos.flush();
        bos.close();
    }

    public static String getStrFile(String filePath){
        if(TextUtils.isEmpty(filePath)){
            return "";
        }
        File file = new File(filePath);
     //   || !file.exists()
        if(file == null){
            return "";
        }
        try {
            final int bufferSize = 1024;
            final char[] buffer = new char[bufferSize];
            final StringBuilder out = new StringBuilder();
            BufferedInputStream stream = new BufferedInputStream(new FileInputStream(file));
            Reader in = new InputStreamReader(stream, "UTF-8");
            int charsRead;
            while((charsRead = in.read(buffer, 0, buffer.length)) > 0) {
                out.append(buffer, 0, charsRead);
            }
            AdLogUtil.Log().d(TAG,"读取的内容 === "+(SspAd.isDebug() ? out.toString() : ""));
            return out.toString();
        } catch (FileNotFoundException e) {
            e.printStackTrace();
            return "";
        } catch (IOException e) {
            e.printStackTrace();
            return "";
        }
    }
}

==> ssp_api-1.3.3.3-sources.jar: com/cloud/hisavana/sdk/common/util/FileUtil.java <==
package com.cloud.hisavana.sdk.common.util;

import static com.cloud.hisavana.sdk.common.util.AdLogUtil.OFF_LINE_TAG;
import static com.cloud.hisavana.sdk.common.util.AdLogUtil.TAG;

import android.Manifest;
import android.content.Context;
import android.graphics.Bitmap;
import android.os.Environment;
import android.text.TextUtils;

import com.cloud.hisavana.sdk.api.config.SspAd;
import com.transsion.core.CoreUtil;
import com.transsion.core.utils.PermissionUtil;
import java.io.BufferedOutputStream;
import java.io.File;

import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
/**
 * @author peng.sun
 * @data 2017/7/5
 * ========================================
 * CopyRight (c) 2017 TRANSSION.Co.Ltd.
 * All rights reserved.
 */

public class FileUtil {

    /**
     * 获得SDCard/Android/data/你的应用的包名/files/ 路径
     *
     * @return
     */
    public static File getAppDateFilePath() {
        Context context = CoreUtil.getContext();
        if (PermissionUtil.lacksPermissions(Manifest.permission.WRITE_EXTERNAL_STORAGE, Manifest.permission.READ_EXTERNAL_STORAGE)) {
            return null;
        }
        return context.getExternalFilesDir(null);
    }


    /**
     * 获得SDCard/android/data/你的应用包名/cache/路径
     *
     * @return
     */
    public static File getAppDateCachePath() {
        Context context = CoreUtil.getContext();
        return context.getExternalCacheDir();
    }

    /**
     * 该方法会判断当前sd卡是否存在，然后选择缓存地址
     *
     * @param context
     * @param uniqueName
     * @return
     */
    public static File getDiskCacheDir(Context context, String uniqueName) {
        String cachePath;
        if (Environment.MEDIA_MOUNTED.equals(Environment.getExternalStorageState()) || !Environment.isExternalStorageRemovable()) {
            cachePath = context.getExternalCacheDir().getPath();
        } else {
            cachePath = context.getCacheDir().getPath();
        }
        return new File(cachePath + File.separator + uniqueName);
    }

    public static void saveBitmapToFile(File dirFile, Bitmap bm, String fileName) throws IOException {
        if (dirFile == null || bm == null || TextUtils.isEmpty(fileName)) {
            return;
        }
        if (!dirFile.exists()) {
            dirFile.mkdir();
        }
        File myCaptureFile = new File(dirFile + File.separator + fileName);
        BufferedOutputStream bos = new BufferedOutputStream(new FileOutputStream(myCaptureFile));
        bm.compress(Bitmap.CompressFormat.JPEG, 80, bos);
        bos.flush();
        bos.close();
    }

    public static void saveBytesToFile(File dir, byte[] bytes, String fileName) throws IOException {
        if (dir == null || bytes == null || bytes.length == 0 || TextUtils.isEmpty(fileName)) {
            return;
        }
        if (!dir.exists()) {
            dir.mkdir();
        }
        File myCaptureFile = new File(dir + File.separator + fileName);
        BufferedOutputStream bos = new BufferedOutputStream(new FileOutputStream(myCaptureFile));
        bos.write(bytes);
        bos.flush();
        bos.close();
    }

    public static String getStrFile(String filePath) {
        if (TextUtils.isEmpty(filePath)) {
            return "";
        }
        File file = new File(filePath);
        if (!file.exists() || !file.isFile()) {
            return "";
        }
        FileReader fileReader = null;
        try {
            fileReader = new FileReader(file);
            char[] bt = new char[1024];
            StringBuffer sb = new StringBuffer();
            int len = 0;
            while ((len = fileReader.read(bt)) != -1) {
                sb.append(bt, 0, len);
            }
            if (sb.length() == 0) return null;
            AdLogUtil.Log().d(OFF_LINE_TAG, (SspAd.isDebug() ? sb.toString() : ""));
            fileReader.close();
            return sb.toString();
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        } finally {
            try {
                if (fileReader != null) {
                    fileReader.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }
}
